@@ -34,7 +34,7 @@ class WebSocketMessageEndpoint(ABC):
         return self._websocket.app
 
     @abstractmethod
-    async def on_receive(self, route: str, data: typing.Any) -> None:
+    async def on_receive(self, route: str, data: typing.Any) -> bool:
         """Override to handle an incoming websocket message"""
 
     async def on_disconnect(self, close_code: int) -> None:
